@@ -15,9 +15,12 @@ import requests
 from matplotlib import cm, colors
 from matplotlib import font_manager as mfonts
 
+from .basemaps import xyz_tiles
+
 try:
 
     import cartopy.crs as ccrs
+    import cartopy.io.img_tiles as cimgt
     from cartopy.mpl.geoaxes import GeoAxes, GeoAxesSubplot
     from cartopy.mpl.gridliner import LATITUDE_FORMATTER, LONGITUDE_FORMATTER
     from PIL import Image
@@ -114,13 +117,15 @@ def check_dependencies():
 # check_dependencies()
 
 
-def get_map(ee_object, proj=None, **kwargs):
+def get_map(ee_object, proj=None, basemap=None, zoom_level=2, **kwargs):
     """
     Wrapper function to create a new cartopy plot with project and adds Earth
     Engine image results
     Args:
         ee_object (ee.Image | ee.FeatureCollection): Earth Engine image result to plot
         proj (cartopy.crs, optional): Cartopy projection that determines the projection of the resulting plot. By default uses an equirectangular projection, PlateCarree
+        basemap (str, optional): Basemap to use. It can be one of ["ROADMAP", "SATELLITE", "TERRAIN", "HYBRID"] or cartopy.io.img_tiles, such as cimgt.StamenTerrain(). Defaults to None. See https://scitools.org.uk/cartopy/docs/v0.19/cartopy/io/img_tiles.html
+        zoom_level (int, optional): Zoom level of the basemap. Defaults to 2.
         **kwargs: remaining keyword arguments are passed to addLayer()
     Returns:
         ax (cartopy.mpl.geoaxes.GeoAxesSubplot): cartopy GeoAxesSubplot object with Earth Engine results displayed
@@ -153,6 +158,17 @@ def get_map(ee_object, proj=None, **kwargs):
         del kwargs["style"]
 
     ax = mpl.pyplot.axes(projection=proj)
+
+    if basemap is not None:
+        if isinstance(basemap, str):
+            if basemap.upper() in ["ROADMAP", "SATELLITE", "TERRAIN", "HYBRID"]:
+                basemap = cimgt.GoogleTiles(url=xyz_tiles[basemap.upper()]["url"])
+
+        try:
+            ax.add_image(basemap, zoom_level)
+        except Exception as e:
+            print("Failed to add basemap: ", e)
+
     add_layer(ax, ee_object, **kwargs)
 
     return ax
@@ -180,6 +196,8 @@ def add_layer(
         ValueError: If `ax` if not of type cartopy.mpl.geoaxes.GeoAxesSubplot '
     """
 
+    import warnings
+
     if (
         isinstance(ee_object, ee.geometry.Geometry)
         or isinstance(ee_object, ee.feature.Feature)
@@ -212,6 +230,11 @@ def add_layer(
         x, y = list(zip(*map_region[0]))
         view_extent = [min(x), max(x), min(y), max(y)]
 
+        if ee_object.bandNames().getInfo() == ["vis-red", "vis-green", "vis-blue"]:
+            warnings.warn(
+                f"The region parameter is not specified. Using the default region {map_region}. Please specify a region if you get a blank image."
+            )
+
     if type(dims) not in [list, tuple, int]:
         raise ValueError("provided dims not of type list, tuple, or int")
 
@@ -257,6 +280,7 @@ def add_layer(
         extent=view_extent,
         origin="upper",
         transform=ccrs.PlateCarree(),
+        zorder=1,
     )
 
     return
@@ -428,9 +452,7 @@ def add_colorbar(
 
     cb = mpl.colorbar.ColorbarBase(cax, norm=norm, alpha=alpha, cmap=cmap, **kwargs)
 
-    if "bands" in vis_keys:
-        cb.set_label(vis_params["bands"])
-    elif label is not None:
+    if label is not None:
         if label_font_size is not None and label_font_family is not None:
             cb.set_label(label, fontsize=label_font_size, family=label_font_family)
         elif label_font_size is not None and label_font_family is None:
@@ -439,12 +461,12 @@ def add_colorbar(
             cb.set_label(label, family=label_font_family)
         else:
             cb.set_label(label)
+    elif "bands" in vis_keys:
+        cb.set_label(vis_params["bands"])
 
     if tick_font_size is not None:
         cb.ax.tick_params(labelsize=tick_font_size)
 
-    return
-
 
 def _buffer_box(bbox, interval):
     """Helper function to buffer a bounding box to the nearest multiple of interval
@@ -1019,8 +1041,8 @@ def add_legend(
     legend_elements=None,
     loc="lower right",
     font_size=14,
-    font_weight='normal',
-    font_color='black',
+    font_weight="normal",
+    font_color="black",
     font_family=None,
 ):
     """Adds a legend to the map. The legend elements can be formatted as:
@@ -1062,7 +1084,7 @@ def add_legend(
         leg = ax.legend(handles=legend_elements, loc=loc, prop=fontdict)
 
         # Change font color If default color is changed.
-        if font_color != 'black':
+        if font_color != "black":
             for text in leg.get_texts():
                 text.set_color(font_color)
         return
