@@ -37,6 +37,17 @@ _palette_dict = {
         "#023858",
     ],
     "dem": ["006633", "E5FFCC", "662A00", "D8D8D8", "F5F5F5"],
+    "dw": [
+        "#419BDF",
+        "#397D49",
+        "#88B053",
+        "#7A87C6",
+        "#E49635",
+        "#DFC35A",
+        "#C4281B",
+        "#A59B8F",
+        "#B39FE1",
+    ],
 }
 
 
